# Generated by roxygen2: do not edit by hand

S3method(coef,imr)
S3method(plot,imr)
S3method(predict,imr)
S3method(print,imr)
S3method(print,summary.imr)
S3method(summary,imr)
export(coef_imr)
export(cv_imr)
export(imr)
export(plot_imr)
export(plot_subgroup_sizes)
export(plot_top_features)
export(predict_imr)
export(summary_imr)
importFrom(grDevices,colorRampPalette)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,image)
importFrom(graphics,par)
importFrom(stats,pnorm)
importFrom(stats,sd)
importFrom(utils,capture.output)
useDynLib(IntegMultiReg, .registration = TRUE)
