% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R, R/wrappers.R
\name{coef.imr}
\alias{coef.imr}
\alias{coef_imr}
\title{Marginal Posterior Inclusion Probabilities of an IMR Fit}
\usage{
\method{coef}{imr}(object, ...)

coef_imr(object, ...)
}
\arguments{
\item{object}{A fitted object of class `"imr"`.}

\item{...}{Unused; present for S3 compatibility.}
}
\value{
A named list with one matrix per platform.  Rows are the subgroups
  containing that platform (labelled by their availability bitstrings) and
  columns are the platform features.
}
\description{
Extracts the posterior mean variable-selection probabilities (the marginal
posterior inclusion probabilities, mPIP) of a fitted model.
}
\seealso{
[imr()]
}
